==> 9.1.2.zip: iClient-JavaScript-9.1.2/test/resources/LayersInfo.js <==
var layersInfo = {
    "completeLineSymbolDisplayed": false,
    "visible": true,
    "maxScale": 0,
    "caption": null,
    "description": "",
    "symbolScalable": false,
    "subLayers": {
        "layers": [{
            "joinItems": null,
            "completeLineSymbolDisplayed": false,
            "ugcLayerType": "VECTOR",
            "displayFilter": null,
            "visible": true,
            "maxScale": 1.350238165824801e-8,
            "fieldValuesDisplayFilter": {"fieldName": "", "values": [], "fieldValuesDisplayMode": "DISABLE"},
            "caption": "continent_T@World",
            "description": "",
            "symbolScalable": false,
            "subLayers": {},
            "type": "UGC",
            "datasetInfo": {
                "charset": null,
                "isReadOnly": false,
                "encodeType": null,
                "recordCount": 0,
                "bounds": {
                    "top": 65.22103117946571,
                    "left": -150.51082428252954,
                    "bottom": -84.34257921576281,
                    "leftBottom": {"x": -150.51082428252954, "y": -84.34257921576281},
                    "right": 154.27853258850513,
                    "rightTop": {"x": 154.27853258850513, "y": 65.22103117946571}
                },
                "name": "continent_T",
                "isFileCache": false,
                "description": null,
                "prjCoordSys": null,
                "type": "TEXT",
                "dataSourceName": "World",
                "tableName": null
            },
            "queryable": false,
            "opaqueRate": 100,
            "minVisibleGeometrySize": 0.4,
            "name": "continent_T@World",
            "bounds": {
                "top": 65.22103117946571,
                "left": -150.51082428252954,
                "bottom": -84.34257921576281,
                "leftBottom": {"x": -150.51082428252954, "y": -84.34257921576281},
                "right": 154.27853258850513,
                "rightTop": {"x": 154.27853258850513, "y": 65.22103117946571}
            },
            "style": {
                "fillGradientOffsetRatioX": 0,
                "markerSize": 2.4,
                "fillForeColor": {"red": 208, "green": 255, "blue": 240, "alpha": 255},
                "fillGradientOffsetRatioY": 0,
                "markerWidth": 0,
                "markerAngle": 0,
                "fillSymbolID": 0,
                "lineColor": {"red": 0, "green": 128, "blue": 0, "alpha": 255},
                "markerSymbolID": 0,
                "lineWidth": 0.1,
                "markerHeight": 0,
                "fillOpaqueRate": 100,
                "fillBackOpaque": true,
                "fillBackColor": {"red": 255, "green": 255, "blue": 255, "alpha": 255},
                "fillGradientMode": "NONE",
                "lineSymbolID": 0,
                "fillGradientAngle": 0
            },
            "displayOrderBy": null,
            "symbolScale": 0,
            "minScale": 3.3755954145620026e-9,
            "representationField": ""
        }],
    },

        "type": "UGC",
        "queryable": false,
        "opaqueRate": 100,
        "minVisibleGeometrySize": 0,
        "name": "World",
        "bounds": {
            "top": 90,
            "left": -180,
            "bottom": -90,
            "leftBottom": {
                "x": -180,
                "y": -90
            },
            "right": 180,
            "rightTop": {
                "x": 180,
                "y": 90
            }
        },
        "symbolScale": 0,
        "minScale": 0
};

var layerInfo = {
    "bounds": {
        "bottom": -84.34257921576281,
        "left": -150.51082428252954,
        "leftBottom": {
            "x": -150.51082428252954,
            "y": -84.34257921576281
        },
        "right": 154.27853258850513,
        "rightTop": {
            "x": 154.27853258850513,
            "y": 65.22103117946571
        },
        "top": 65.22103117946571
    },
    "caption": "continent_T@World",
    "completeLineSymbolDisplayed": false,
    "datasetInfo": {
        "bounds": {
            "bottom": -84.34257921576281,
            "left": -150.51082428252954,
            "leftBottom": {
                "x": -150.51082428252954,
                "y": -84.34257921576281
            },
            "right": 154.27853258850513,
            "rightTop": {
                "x": 154.27853258850513,
                "y": 65.22103117946571
            },
            "top": 65.22103117946571
        },
        "charset": null,
        "dataSourceName": "World",
        "description": null,
        "encodeType": null,
        "isFileCache": false,
        "isReadOnly": false,
        "name": "continent_T",
        "prjCoordSys": null,
        "recordCount": 0,
        "tableName": null,
        "type": "TEXT"
    },
    "description": "",
    "displayFilter": null,
    "displayOrderBy": null,
    "fieldValuesDisplayFilter": {
        "fieldName": "",
        "fieldValuesDisplayMode": "DISABLE",
        "values": []
    },
    "joinItems": null,
    "maxScale": 1.350238165824801E-8,
    "minScale": 3.3755954145620026E-9,
    "minVisibleGeometrySize": 0.4,
    "name": "continent_T@World.1",
    "opaqueRate": 100,
    "queryable": false,
    "representationField": "",
    "style": {
        "fillBackColor": {
            "alpha": 255,
            "blue": 255,
            "green": 255,
            "red": 255
        },
        "fillBackOpaque": true,
        "fillForeColor": {
            "alpha": 255,
            "blue": 240,
            "green": 255,
            "red": 208
        },
        "fillGradientAngle": 0,
        "fillGradientMode": "NONE",
        "fillGradientOffsetRatioX": 0,
        "fillGradientOffsetRatioY": 0,
        "fillOpaqueRate": 100,
        "fillSymbolID": 0,
        "lineColor": {
            "alpha": 255,
            "blue": 0,
            "green": 128,
            "red": 0
        },
        "lineSymbolID": 0,
        "lineWidth": 0.1,
        "markerAngle": 0,
        "markerHeight": 0,
        "markerSize": 2.4,
        "markerSymbolID": 0,
        "markerWidth": 0
    },
    "subLayers": {},
    "symbolScalable": false,
    "symbolScale": 0,
    "type": "UGC",
    "ugcLayerType": "VECTOR",
    "visible": true
};

==> 11.1.1.zip: iClient-JavaScript-11.1.1/test/resources/LayersInfo.js <==
var layersInfo = {
    "completeLineSymbolDisplayed": false,
    "visible": true,
    "maxScale": 0,
    "caption": null,
    "description": "",
    "symbolScalable": false,
    "subLayers": {
        "layers": [{
            "joinItems": null,
            "completeLineSymbolDisplayed": false,
            "ugcLayerType": "VECTOR",
            "displayFilter": null,
            "visible": true,
            "maxScale": 1.350238165824801e-8,
            "fieldValuesDisplayFilter": {"fieldName": "", "values": [], "fieldValuesDisplayMode": "DISABLE"},
            "caption": "continent_T@World",
            "description": "",
            "symbolScalable": false,
            "subLayers": {},
            "type": "UGC",
            "datasetInfo": {
                "charset": null,
                "isReadOnly": false,
                "encodeType": null,
                "recordCount": 0,
                "bounds": {
                    "top": 65.22103117946571,
                    "left": -150.51082428252954,
                    "bottom": -84.34257921576281,
                    "leftBottom": {"x": -150.51082428252954, "y": -84.34257921576281},
                    "right": 154.27853258850513,
                    "rightTop": {"x": 154.27853258850513, "y": 65.22103117946571}
                },
                "name": "continent_T",
                "isFileCache": false,
                "description": null,
                "prjCoordSys": null,
                "type": "TEXT",
                "dataSourceName": "World",
                "tableName": null
            },
            "queryable": false,
            "opaqueRate": 100,
            "minVisibleGeometrySize": 0.4,
            "name": "continent_T@World",
            "bounds": {
                "top": 65.22103117946571,
                "left": -150.51082428252954,
                "bottom": -84.34257921576281,
                "leftBottom": {"x": -150.51082428252954, "y": -84.34257921576281},
                "right": 154.27853258850513,
                "rightTop": {"x": 154.27853258850513, "y": 65.22103117946571}
            },
            "style": {
                "fillGradientOffsetRatioX": 0,
                "markerSize": 2.4,
                "fillForeColor": {"red": 208, "green": 255, "blue": 240, "alpha": 255},
                "fillGradientOffsetRatioY": 0,
                "markerWidth": 0,
                "markerAngle": 0,
                "fillSymbolID": 0,
                "lineColor": {"red": 0, "green": 128, "blue": 0, "alpha": 255},
                "markerSymbolID": 0,
                "lineWidth": 0.1,
                "markerHeight": 0,
                "fillOpaqueRate": 100,
                "fillBackOpaque": true,
                "fillBackColor": {"red": 255, "green": 255, "blue": 255, "alpha": 255},
                "fillGradientMode": "NONE",
                "lineSymbolID": 0,
                "fillGradientAngle": 0
            },
            "displayOrderBy": null,
            "symbolScale": 0,
            "minScale": 3.3755954145620026e-9,
            "representationField": ""
        }],
    },

        "type": "UGC",
        "queryable": false,
        "opaqueRate": 100,
        "minVisibleGeometrySize": 0,
        "name": "World",
        "bounds": {
            "top": 90,
            "left": -180,
            "bottom": -90,
            "leftBottom": {
                "x": -180,
                "y": -90
            },
            "right": 180,
            "rightTop": {
                "x": 180,
                "y": 90
            }
        },
        "symbolScale": 0,
        "minScale": 0
};

var layerInfo = {
    "bounds": {
        "bottom": -84.34257921576281,
        "left": -150.51082428252954,
        "leftBottom": {
            "x": -150.51082428252954,
            "y": -84.34257921576281
        },
        "right": 154.27853258850513,
        "rightTop": {
            "x": 154.27853258850513,
            "y": 65.22103117946571
        },
        "top": 65.22103117946571
    },
    "caption": "continent_T@World",
    "completeLineSymbolDisplayed": false,
    "datasetInfo": {
        "bounds": {
            "bottom": -84.34257921576281,
            "left": -150.51082428252954,
            "leftBottom": {
                "x": -150.51082428252954,
                "y": -84.34257921576281
            },
            "right": 154.27853258850513,
            "rightTop": {
                "x": 154.27853258850513,
                "y": 65.22103117946571
            },
            "top": 65.22103117946571
        },
        "charset": null,
        "dataSourceName": "World",
        "description": null,
        "encodeType": null,
        "isFileCache": false,
        "isReadOnly": false,
        "name": "continent_T",
        "prjCoordSys": null,
        "recordCount": 0,
        "tableName": null,
        "type": "TEXT"
    },
    "description": "",
    "displayFilter": null,
    "displayOrderBy": null,
    "fieldValuesDisplayFilter": {
        "fieldName": "",
        "fieldValuesDisplayMode": "DISABLE",
        "values": []
    },
    "joinItems": null,
    "maxScale": 1.350238165824801E-8,
    "minScale": 3.3755954145620026E-9,
    "minVisibleGeometrySize": 0.4,
    "name": "continent_T@World.1",
    "opaqueRate": 100,
    "queryable": false,
    "representationField": "",
    "style": {
        "fillBackColor": {
            "alpha": 255,
            "blue": 255,
            "green": 255,
            "red": 255
        },
        "fillBackOpaque": true,
        "fillForeColor": {
            "alpha": 255,
            "blue": 240,
            "green": 255,
            "red": 208
        },
        "fillGradientAngle": 0,
        "fillGradientMode": "NONE",
        "fillGradientOffsetRatioX": 0,
        "fillGradientOffsetRatioY": 0,
        "fillOpaqueRate": 100,
        "fillSymbolID": 0,
        "lineColor": {
            "alpha": 255,
            "blue": 0,
            "green": 128,
            "red": 0
        },
        "lineSymbolID": 0,
        "lineWidth": 0.1,
        "markerAngle": 0,
        "markerHeight": 0,
        "markerSize": 2.4,
        "markerSymbolID": 0,
        "markerWidth": 0
    },
    "subLayers": {},
    "symbolScalable": false,
    "symbolScale": 0,
    "type": "UGC",
    "ugcLayerType": "VECTOR",
    "visible": true
};

var legendInfo = {
  "layerLegends": [
      {
        "subLayerLegends": null,
        "layerType": "UGC",
        "legends": [
          {
            "imageData": "iVBORw0KGgoAAAANSUhEUgAAABAAAAAQCAYAAAAf8/9hAAAAbUlEQVR4XmNgGAV4gUFAgYBhYNEBdHGiAVDzAyD+jy5ONABqvgAywCCgKAFdjiAwCioqANEgA8hyBVDTByi9AeKKAgF0NXgByNkGASUOIAx1xQN0NTgBesiT5A2YjUAnK8DEYAaAAhVJ6SiAAgABsy5InB3ROAAAAABJRU5ErkJggg==",
            "values": null,
            "width": 16,
            "label": "continent_T@World",
            "contentType": "image/png",
            "url": "https://iserver.supermap.io:443/iserver/manager/static/Theme/image/Text.png",
            "height": 16
          }
        ],
        "maxScale": 1.350238165824801e-8,
        "layerName": "continent_T@World",
        "minScale": 0
      }
  ]
}
